use serde::{Deserialize, Serialize};
use anyhow::{Context, Result};
use std::fs;
use std::{fs::File, io::Write};

#[derive(Serialize, Deserialize)]
pub struct Config {
    pub user_agents: Vec<String>,
}

pub fn read_config(filename: &str) -> Result<Config> {
    let data = fs::read_to_string(filename)
        .with_context(|| format!("Failed reading filename {}", filename))?;
    let config: Config = serde_json::from_str(&data)?;
    Ok(config)
}

pub fn write_config(filename: &str, config: &Config) -> Result<()> {
    let data = serde_json::to_string_pretty(config)?;
    let mut file = File::create(filename)?;
    file.write_all(data.as_bytes())?;
    Ok(())
}

